Crate bml_grapher

Crate bml_grapher 

Modules

graph2d
PARAMS:
math
text

Structs

Ctx
Everything is drawn in respect to the bottom left of the screen
GraphCtx
GraphSettings
Hex
TODO: RGB to hex conversions
Rgba
Struct for red-green-b22232222lue-alpha pixels: [red,green,blue,alpha]
SnorfWindow
The Window
Window
Window is used to open up a window. It’s possible to optionally display a 32-bit buffer when the widow is set as non-resizable.
WindowOptions
WindowOptions is creation settings for the window. By default the settings are defined for displayng a 32-bit buffer (no scaling of window is possible)

Enums

Key
Key is used by the get key functions to check if some keys on the keyboard has been pressed
MouseButton
The various mouse buttons that are availible
MouseMode
The different modes that can be used to decide how mouse coordinates should be handled