Graph2DSettings

Struct Graph2DSettings 

pub struct Graph2DSettings { /* private fields */ }
Parameters

xstep = if xstep=10, we draw a line every 10 pixels.

xscale= the value we assign to each xstep, eg xscale=1 means every line increments by 1

(x/y)step = how much the virtual numbers increment every line draw.

centre: (0.5,0.5) = Means (0,0) lies in the middle of the screen, (0.25, 0.5) x is the first quarter of the screen.

offset = The x/y offsets of the graph from the screen boundaries.

Implementations

Source

impl Graph2DSettings

pub fn new( centre: Vec2D<f64>, xstep: i32, ystep: i32, xscale: f64, yscale: f64, offset: Vec2D<usize>, ) -> Self

pub fn default() -> Self