pub struct Graph2DSettings { /* private fields */ }Expand description
Parameters
xstep = if xstep=10, we draw a line every 10 pixels.
xscale= the value we assign to each xstep, eg xscale=1 means every line increments by 1
(x/y)step = how much the virtual numbers increment every line draw.
centre: (0.5,0.5) = Means (0,0) lies in the middle of the screen, (0.25, 0.5) x is the first quarter of the screen.
offset = The x/y offsets of the graph from the screen boundaries.
Implementations